`timescale 1ns / 1ps
//******************************************************************************
// File Name            : vga_out_ap.v
//------------------------------------------------------------------------------
// Function             : vga_out_ap top
//                        
//------------------------------------------------------------------------------
// Designer             : yokomizo@himwari_co 
//------------------------------------------------------------------------------
// History
// -.-- 2016/10/14
//******************************************************************************
module vga_out_ap(
  clk_100m,
  rst,
  da_en,
  da_r,
  da_g,
  da_b,
  vsync,
  hsync,
  led_0,
  sw_mov,
  sw_mode
      );
	
  input clk_100m;
  input rst;
  output da_en;
  output [3:0]da_r;
  output [3:0]da_g;
  output [3:0]da_b;
  output vsync;
  output hsync;
  output led_0;
  input  [4:0]sw_mov;
  input  [2:0]sw_mode;
  //
  wire clk_i_100m;
  wire clk;
  wire rstb;
  //
  reg    led_0;
  reg [25:0]     led_cnt;
  //
  wire in_a_da_en;
  wire [7:0]in_a_da_r;
  wire [7:0]in_a_da_g;
  wire [7:0]in_a_da_b;
  // 
  //wire sync;
  wire tmg_sync;
  wire h_c_en;
  wire [9:0] v_c;
  wire [9:0] h_c;
  wire [7:0]da_r_tmp;
  wire [7:0]da_g_tmp;
  wire [7:0]da_b_tmp;
  wire test_mode;
  wire locked;
  wire rst_unlock;
  //uart
  wire [7:0]rx_data;
  wire [7:0]rx_data_dmy;
  wire rx_data_en;
  wire tx_busy;
  wire rx_busy;
  
  
  assign rst_unlock = ((rst==1'b1)||(locked==1'b0))?1'b1:1'b0;
  
  assign rstb = ~rst_unlock;
  assign test_mode = 1'b0;
  assign da_r = da_r_tmp[7:4];
  assign da_g = da_g_tmp[7:4];
  assign da_b = da_b_tmp[7:4];
 
 clk_wiz_0 clkk_wiz_0
   (
  // Clock in ports
   .clk_in1(clk_100m),
   // Clock out ports  
   .clk_out1(clk_i_100m),
   .clk_out2(clk), //25MHz
   // Status and control signals               
   .reset(rst), 
   .locked(locked)            
   );  
   
//LED_
always @ (posedge clk or negedge rstb )
if (rstb==1'b0)
  begin 
    led_cnt <= 26'b0;
    led_0 <= 1'b1;
  end
else
  if (led_cnt == 26'd40000000)
    begin
      led_cnt <= 26'b0;
       led_0 <= ~led_0;
    end
  else
    begin
       led_cnt <= led_cnt + 26'd1;
       led_0 <= led_0;
    end 



hls_blk hls_blk(
  .clk_100m(    clk_i_100m),      
  .clk(    clk),      
  .rst(     rst_unlock),   
  .h_c_en(h_c_en),
  .v_c(v_c),
  .h_c(h_c),      
  .sw_mov(sw_mov),
  .sw_mode(sw_mode),
  .gen_da_en(in_a_da_en),
  .gen_da_r( in_a_da_r), 
  .gen_da_g( in_a_da_g), 
  .gen_da_b( in_a_da_b) 
);


vga_if vga_if (
  .clk(         clk),           
  .rstb(        rstb),     
  .h_c_en(   h_c_en),     
  .out_hsync( hsync),   
  .out_vsync( vsync),   
  .v_c(         v_c),           
  .h_c(         h_c),  
  .in_a_da_en(  in_a_da_en),      
  .in_a_da_r(   in_a_da_r),       
  .in_a_da_g(   in_a_da_g),       
  .in_a_da_b(   in_a_da_b),  
  .out_da_r(    da_r_tmp),      
  .out_da_g(    da_g_tmp),      
  .out_da_b(    da_b_tmp),      
  .out_da_en(   da_en)        
);

endmodule

